#ifndef NT2_INCLUDE_FUNCTIONS_GAMPDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_GAMPDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/gampdf.hpp>

#endif
